@@ -387,6 +387,9 @@ class Update(MethodsInterface):
         check_status = dv.GetBool('update.cl_update_check_rep_set')
         git = self.getGit()
         working_host = ''
+        # проверка необходимости синхронизации других оверлеев
+        if self.clVars.Get("cl_update_inner_other_set"):
+            self.clVars.Write("cl_update_other_set", self.clVars.Get("cl_update_inner_other_set"), header="update")
         if 'cl_update_rep_list' in dv.allVars and dv.Get('cl_update_rep_list'):
             # Берем первый доступный хостинг из списка
             for host_urls, host in dv.Get('cl_update_inner_rep_list'):
@@ -1574,10 +1577,6 @@ class Update(MethodsInterface):
     def create_binhost_data(self):
         dv = self.clVars
         last_ts = dv.Get('cl_update_last_timestamp')
-        a = dv.Get('cl_update_binhost')
-        c = self.clVars.getIniVar('cl_update_binhost')
-        d = dv.Get('cl_update_binhost_choice')
-        b = dv.GetBool('cl_update_binhost_set')
         if (not dv.Get('cl_update_binhost_choice') and not dv.GetBool('cl_update_binhost_set')) \
                 or dv.Get('cl_update_binhost_choice') == 'auto':
             if dv.Get('cl_update_binhost_stable_opt_set'):
@@ -1591,7 +1590,6 @@ class Update(MethodsInterface):
                 dv.Write('cl_update_binhost_set', "on")
             binhost_list = [dv.Get('cl_update_binhost')]
 
-            #dv.Write('cl_update_binhost_set', "off")
         self.binhosts_data = Binhosts(
             # значение малозначимо, поэтому берётся из собирающей системы
             dv.GetInteger('cl_update_binhost_timeout'),
