@@ -621,13 +621,28 @@ class VariableClUpdateOtherSet(Variable):
     Обновить остальные оверлеи
     """
     type = "bool"
-    value = "off"
-    opt = ["-o", "--update-other"]
+    value = "on"
+
 
     def init(self):
         self.help = _("update other overlays")
         self.label = _("Update other overlays")
 
+    def get(self):
+        if self.Get('cl_update_inner_other_set'):
+            return self.Get('cl_update_inner_other_set')
+        return self.value
+
+
+class VariableClUpdateInnerOtherSet(Variable):
+    type = "string"
+    value = ''
+    opt = ["-o", "--update-other"]
+
+    def get(self):
+        if self.value in ["on", "off"]:
+            return True
+        return False
 
 class VariableClUpdateOtherRepData(ReadonlyTableVariable):
     """
