@@ -69,11 +69,13 @@ class Wsdl(WsdlBase):
                                         'cl_update_binhost_stable_opt_set',
                                         'cl_update_binhost_recheck_set',
                                         'cl_update_with_bdeps_opt_set',
-                                        'cl_update_binhost_choice'
+                                        'cl_update_other_set'
+
                                     ),
                                     expert=(
+                                        'cl_update_binhost_choice',
                                         'cl_update_sync_only_set',
-                                        'cl_update_other_set',
+
                                         'cl_update_pretend_set',
                                         'cl_update_sync_rep',
                                         'cl_update_emergelist_set',
@@ -92,6 +94,7 @@ class Wsdl(WsdlBase):
                                         'cl_update_cleanpkg_set',
                                         'cl_update_branch_data',
                                         'cl_templates_locate',
+                                        'cl_update_inner_other_set',
                                         'cl_verbose_set', 'cl_dispatch_conf'),
                                     next_label=_("Run"))]},
         #
